@@ -169,11 +169,11 @@ Question:
 Visible context strings (titles, axes, legends, headers):
 {ctx}
 
-Write a concise conclusion (~140-200 words) with:
-- Headline (one sentence answering the question).
-- Evidence (4-5 bullets referencing panels/axes/legend groups seen in the figures).
-- Limitations (1-2 bullets; avoid quoting numbers unless present in context).
-- Next step (1 bullet).
+Write a concise conclusion (~200-260 words) with:
+- <strong>Headline</strong> (one sentence answering the question).
+- <strong>Evidence</strong> (6-8 bullets referencing panels/axes/legend groups seen in the figures and explaining the plots/tables  vis-a-vis the query). Explain all the oupupt comprehensively in details.
+- <strong>Limitations</strong> (1 bullets; avoid quoting numbers unless present in context).
+- <strong>Next step</strong> (1 bullet).
 """
 
 def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) -> str:
@@ -188,18 +188,18 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
         ctx=json.dumps(visible, ensure_ascii=False, indent=2)
     )
 
-    prof = _prof.get_profile("vision2text") or _prof.get_profile("admin")
+    prof = _prof.get_profile("image2text") or _prof.get_profile("admin") 
     if not prof:    
         return (
             "<div class='smx-alert smx-alert-warn'>"
-                "No LLM profile configured for 'Vision2Text'. Please contact your Administrator."
+                "No LLM profile is configured for Image2Text. Please, do that in the Admin panel or contact your Administrator."
             "</div>"
         )
     _client = _prof.get_client(prof)
     _provider = (prof.get("provider") or "").lower()
     _model = prof.get("model") or ""
 
-    # Google GenAI (Gemini) — multimodal
+    # Google
     if _provider == "google":
         try:
             parts = [types.Part.from_text(text=user)]
@@ -216,8 +216,9 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
             if txt.strip():
                 return txt.strip()
         except Exception:
-            pass  # fall through to text-only
+             pass  # Fall through to the chat.completions fallback implemented below.
     
+    # Openai
     elif _provider == "openai" and _model in GPT_MODELS_LATEST:
         # Use the Responses API with multimodal input (text + up to 4 images)
         try:
@@ -240,10 +241,8 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
             if txt.strip():
                 return txt.strip()
         except Exception:
-            # If the Responses path fails for any reason, fall through to the
-            # chat.completions fallback implemented below.
-            pass
-    
+            pass  # Fall through to the chat.completions fallback implemented below.
+                
     # Anthropic
     elif _provider == "anthropic":
         try:
@@ -261,8 +260,9 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
             )
             return response.content[0].text.strip()   
         except Exception:
-            pass  # fall through
-
+             pass  # Fall through to the chat.completions fallback implemented below.
+    
+    # OpenAI SDK
     else: # provider in {"openai","xai","deepseek","moonshotai","alibaba"}:
         try:
             parts = [{"type":"text","text": user}]
@@ -271,7 +271,7 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
                     parts.append({"type":"image_url","image_url":{"url": f"data:image/png;base64,{b64}"}})
             resp = _client.chat.completions.create(
                 model=_model,
-                temperature=0.2,
+                temperature=0.3,
                 messages=[
                     {"role":"system","content":_SYSTEM_VISION},
                     {"role":"user","content":parts},
@@ -280,29 +280,10 @@ def phrase_commentary_vision(context: Dict[str, Any], images_b64: List[str]) ->
             )
             return (resp.choices[0].message.content or "").strip()
         except Exception:
-            pass  # fall through
+             pass  # Fall through to the chat.completions fallback implemented below.
 
     # Text-only fallback via Responses API
-    try:
-        args = set_args(model=_model, instructions=_SYSTEM_VISION,
-                        input=user, previous_id=None, store=False,
-                        reasoning_effort="minimal", verbosity="low")
-        resp = _client.responses.create(**args)
-        return _out(resp)
-    except Exception:
-        # Classic chat fallback
-        try:
-            resp = _client.chat.completions.create(
-                model=_model,
-                temperature=0.2,
-                messages=[{"role":"system","content":_SYSTEM_VISION},
-                          {"role":"user","content":user}],
-                max_tokens=600,
-            )
-            return (resp.choices[0].message.content or "").strip()
-        except Exception:
-            return "Insufficient context to comment usefully."
-
+    return "Insufficient context to comment usefully."
 
 def wrap_html(card_text: str) -> str:
     return f"""
