@@ -14,7 +14,7 @@ from .file_processor import process_admin_pdf_files
 from google.genai import types
 from .vector_db import query_embeddings
 from .vectorizer import embed_text
-from syntaxmatrix.settings.prompts import SMX_PROMPT_PROFILE, SMX_PROMPT_INSTRUCTIONS, SMX_WEBSITE_DESCRIPTION
+from syntaxmatrix.settings.prompts import SMXAI_CHAT_ID, SMXAI_CHAT_INSTRUCTIONS, SMX_WEBSITE_DESCRIPTION
 from typing import List, Generator
 from .auth import init_auth_db
 from . import profiles as _prof
@@ -69,8 +69,8 @@ class SyntaxMUI:
         self.ui_mode = ui_mode
         self.theme_toggle_enabled = False
         self.user_files_enabled = False
-        self.prompt_profile = SMX_PROMPT_PROFILE
-        self.prompt_instructions = SMX_PROMPT_INSTRUCTIONS    
+        self.ai_chat_id = SMXAI_CHAT_ID
+        self.ai_chat_instructions = SMXAI_CHAT_INSTRUCTIONS    
         self.website_description = SMX_WEBSITE_DESCRIPTION
 
         db.init_db()
@@ -443,11 +443,11 @@ class SyntaxMUI:
     #  *********** LLM CLIENT HELPERS  **********************
     # ──────────────────────────────────────────────────────────────
     def set_prompt_profile(self, profile):
-        self.prompt_profile = profile
+        self.ai_chat_id = profile
     
 
     def set_prompt_instructions(self, instructions):
-        self.prompt_instructions = instructions
+        self.ai_chat_instructions = instructions
 
 
     def set_website_description(self, desc):
@@ -718,31 +718,12 @@ class SyntaxMUI:
     
 
     def process_query_stream(self, query: str, context: str, history: list, stream=True) -> Generator[str, None, None]:
-        """
-        Streaming generator. Uses the prepared args already set by set_stream_args().
-        Do NOT clobber `query` from request.form here - this endpoint is a GET (SSE).
-        """
-        try:
-            from flask import request, has_request_context
-            if has_request_context() and request.method == "POST":
-                override = (request.form.get("user_query") or "").strip()
-                if override:
-                    query = override
-        except Exception:
-            pass
-
-        # seed the UI/session so classify intent still works the same way
-        session["user_query"] = query
-        session.modified = True
-
-        if not (query or "").strip():
-            # End quietly; the route wrapper will handle 'done' with empty text if needed
-            return
-
+       
         if not self._chat_profile:
             chat_profile = _prof.get_profile("chat") or _prof.get_profile("admin")
             if not chat_profile:
-                yield "Error: Chat profile is not configured."
+                yield """<p style='color:red;'>Error: Chat profile is not configured. Add a chat profile inside the admin panel or contact your administrator.</p>
+                """
                 return
             self._chat_profile = chat_profile
             self._chat_profile['client'] = _prof.get_client(chat_profile)
@@ -752,7 +733,7 @@ class SyntaxMUI:
         _model = self._chat_profile['model']
 
         _contents = f"""
-            {self.prompt_instructions}\n\n 
+            {self.ai_chat_instructions}\n\n 
             Question: {query}\n
             Context: {context}\n\n
             History: {history}\n\n
@@ -765,7 +746,7 @@ class SyntaxMUI:
                     types.Content(
                         role="user",
                         parts=[
-                            types.Part.from_text(text=f"{self.prompt_profile}\n\n{_contents}"),
+                            types.Part.from_text(text=f"{self.ai_chat_id}\n\n{_contents}"),
                         ],
                     ),
                 ]
@@ -778,14 +759,14 @@ class SyntaxMUI:
         
             elif _provider == "openai" and _model in self.gpt_models_latest():  # GPt 5 series
                 input_prompt = (
-                    f"{self.prompt_instructions}\n\n"
+                    f"{self.ai_chat_instructions}\n\n"
                     f"Generate a response to this query:\n{query}\n"
                     f"based on this given context:\n{context}\n\n"
                     f"(Use conversation continuity if available.)"
                 )
                 sid = self.get_session_id()
                 prev_id = self._gpt_models_latest_prev_resp_ids.get(sid)
-                args = set_args(model=_model, instructions=self.prompt_profile, input=input_prompt, previous_id=prev_id, store=True)
+                args = set_args(model=_model, instructions=self.ai_chat_id, input=input_prompt, previous_id=prev_id, store=True)
                 
                 with _client.responses.stream(**args) as s:
                     for event in s:
@@ -800,7 +781,7 @@ class SyntaxMUI:
             elif _provider == "anthropic":
                 with _client.messages.stream(
                     max_tokens=1024,
-                    messages=[{"role": "user", "content":f"{self.prompt_profile}\n\n {_contents}"},],
+                    messages=[{"role": "user", "content":f"{self.ai_chat_id}\n\n {_contents}"},],
                     model=_model,
                 ) as stream:
                     for text in stream.text_stream:
@@ -809,15 +790,15 @@ class SyntaxMUI:
                     response = _client.messages.create(
                     model=_model,
                     max_tokens=1024,
-                    system=self.prompt_profile,
+                    system=self.ai_chat_id,
                     messages=[{"role": "user", "content":_contents}],
                     stream=False,
                 )
                     
             else:  # Assumes standard openai_sdk
                 openai_sdk_prompt = [
-                    {"role": "system", "content": self.prompt_profile},
-                    {"role": "user", "content": f"{self.prompt_instructions}\n\nGenerate response to this query: {query}\nbased on this context:\n{context}\nand history:\n{history}\n\nUse conversation continuity if available.)"},
+                    {"role": "system", "content": self.ai_chat_id},
+                    {"role": "user", "content": f"{self.ai_chat_instructions}\n\nGenerate response to this query: {query}\nbased on this context:\n{context}\nand history:\n{history}\n\nUse conversation continuity if available.)"},
                 ]
                 response = _client.chat.completions.create(
                     model=_model, 
@@ -837,13 +818,15 @@ class SyntaxMUI:
         if not self._chat_profile:
             chat_profile = _prof.get_profile("chat") or _prof.get_profile("admin")
             if not chat_profile:
-                return "Error: check your profiles setup"
+                return """<p style='color:red;'>Error: Chat profile is not configured. Add a chat profile inside the admin panel or contact your administrator.</p>
+                """
+                return
                  
             self._chat_profile = chat_profile
             self._chat_profile['client'] = _prof.get_client(chat_profile) 
         
         _contents = f"""
-                    {self.prompt_instructions}\n\n 
+                    {self.ai_chat_instructions}\n\n 
                     Question: {query}\n
                     Context: {context}\n\n
                     History: {history}\n\n
@@ -851,8 +834,8 @@ class SyntaxMUI:
                 """
         
         openai_sdk_prompt = [
-                {"role": "system", "content": self.prompt_profile},
-                {"role": "user", "content": f"""{self.prompt_instructions}\n\n
+                {"role": "system", "content": self.ai_chat_id},
+                {"role": "user", "content": f"""{self.ai_chat_instructions}\n\n
                                                 Generate response to this query: {query}\n
                                                 based on this context:\n{context}\n
                                                 and history:\n{history}\n\n
@@ -869,7 +852,7 @@ class SyntaxMUI:
             try:
                 response = _client.models.generate_content(
                     model=_model,
-                    contents=f"{self.prompt_profile}\n\n{_contents}"
+                    contents=f"{self.ai_chat_id}\n\n{_contents}"
                 )
                 answer = response.text
                 
@@ -884,7 +867,7 @@ class SyntaxMUI:
             """
             # Prepare the prompt with conversation history and context
             input = (
-                f"{self.prompt_instructions}\n\n"
+                f"{self.ai_chat_instructions}\n\n"
                 f"Generate a response to this query:\n{query}\n"
                 f"based on this given context:\n{context}\n\n"
                 f"(Use conversation continuity if available.)"
@@ -895,7 +878,7 @@ class SyntaxMUI:
             
             args = set_args(
                 model=_model,
-                instructions=self.prompt_profile,
+                instructions=self.ai_chat_id,
                 input=input,
                 previous_id=prev_id,
                 store=True,
@@ -920,7 +903,7 @@ class SyntaxMUI:
                 response = _client.messages.create(
                     model=_model,
                     max_tokens=1024,
-                    system=self.prompt_profile,
+                    system=self.ai_chat_id,
                     messages=[{"role": "user", "content":_contents}],
                     stream=False,
                 )
@@ -953,7 +936,7 @@ class SyntaxMUI:
         return openai_sdk_process_query()
 
 
-    def ai_generate_code(self, question, df):
+    def ai_generate_code(self, question, intent, df):
     
         if not self._coding_profile:            
             coding_profile = _prof.get_profile("coding") or _prof.get_profile("admin")
@@ -974,62 +957,53 @@ class SyntaxMUI:
         _model = self._coding_profile['model']
 
         context = f"Columns: {list(df.columns)}\n\nDtypes: {df.dtypes.astype(str).to_dict()}\n\n"
-        
-        Linear_regression = """
-            <Instruction for Generating Multiple Linear Regression Analysis Code>
-                You are a data science code generation assistant. Your task is to produce a complete, executable Python script that performs a multiple linear regression analysis based on a user's specific request, using a provided dataset (`df`).
-        
-            <Steps to Generate the Code>
-                <dataset loading>:
-                Assume the dataset is accessible (e.g., via an uploaded file or a provided path).
-                Use pandas (pd) to load the dataset into a DataFrame named df. The specific loading command (pd.read_csv, etc.) should match the dataset's format as implied by the user (e.g., if the user mentions diabetes_dataset.csv, use pd.read_csv('diabetes_dataset.csv')).
-                Print the first few rows (df.head()) and descriptive statistics (df.describe()) of the loaded DataFrame to verify successful loading.
+        ALLOWED_COLUMNS = list(df.columns)
 
-                <Variable Identification>:
-                    <carefully analyze the user's query to identify>:
-                    The target variable (dependent variable) to be predicted (e.g., "predict the level of the liver enzyme GGT").
-                    The specific predictor variables (independent variables) to be used in the model (e.g., "BMI, Waist_Circumference, Alcohol_Consumption, and HbA1c").
-                    Examine the column names of the loaded DataFrame (df.columns) to find the exact column names corresponding to the variables identified in the query. Ensure the column names used in the code exactly match those in the dataset.
-
-                <Data Preparation>:
-                    Select the identified predictor variables and create a feature matrix X.
-                    Select the identified target variable and create a target vector y.
-                    Handle any potential missing values if necessary (e.g., using dropna() or imputation, though for simplicity, dropping rows with missing values in relevant columns is often acceptable for initial analysis).
-                
-                <Model Creation and Training>:
-                    Import necessary modules from sklearn (train_test_split, LinearRegression, mean_squared_error, r2_score).
-                    Split the data into training and testing sets using train_test_split (e.g., 80% train, 20% test).
-                    Instantiate a LinearRegression model.
-                    Fit the model to the training data (model.fit(X_train, y_train)).
-                    Model Evaluation:
-                    Use the trained model to make predictions on the test set (y_pred = model.predict(X_test)).
-                    Calculate performance metrics like R-squared (r2_score) and Mean Squared Error (mean_squared_error) to evaluate how well the model fits the data on the test set.
-                    
-                <Result Interpretation>:
-                    Extract the model's coefficients (model.coef_) and intercept (model.intercept_).
-                    Print the intercept and a list of feature names paired with their corresponding coefficients.
-                    Calculate the absolute values of the coefficients to assess the relative importance of each predictor variable.
-                    Provide a clear interpretation:
-                    Explain what each coefficient means in the context of the problem (e.g., "A 1 unit increase in [Feature Name], holding other variables constant, is associated with a [Coefficient Value] unit change in [Target Variable Name]").
-                    Rank the predictor variables by the absolute value of their coefficients to indicate their relative contribution to the prediction.
-                    
-                <Output Formatting>:
-                    Structure the printed output clearly using section headers (e.g., "=== Multiple Linear Regression Results ===", "=== Interpretation ===").
-                    Ensure the final code is self-contained, uses appropriate variable names, and includes necessary import statements.
-                    Add a comment reminding the user to ensure column names match their actual dataset if they adapt the code.
-        """
-        
         ai_profile = f"""
-        You are a data science code generation assistant. Your task is to produce a complete, executable Python script that performs a multiple linear regression analysis based on a user's specific request, using a provided dataset (`df`).
+        You are a senior Python data scientist writing production-quality, **runnable** code for a Jupyter-like kernel. You are given a pandas DataFrame named `df`. Begin ONLY the data already in `df` (no file I/O).
         """
 
         instructions = f"""
-            Write clean, working Python code that answers the question below. 
-            DO NOT explain, just output the code only.
-            Question: {question}\n
-            Context: {context}\n\n
-            Output only the working code needed. Assume df is already defined.
-            Produce at least one visible result: (syntaxmatrix.display.show(), display(), plt.show()).
+        ### Context
+        - Schema (names → dtypes): {context}
+        - Row count: {len(df)}
+        - Task: {question}
+        - Task type: {intent}
+        - Allowed columns: {ALLOWED_COLUMNS}
+
+        ### Hard requirements
+        1) **Code only**. No markdown, no comments, no explanations.
+        2) Import everything you use explicitly. Assume: pandas≥2, numpy≥1.25, matplotlib≥3.8, seaborn≥0.13, scikit-learn≥1.4 are available.
+        3) **Avoid deprecated / removed APIs**, e.g.:
+        - pandas: do not use `.append`, `.ix`, `.as_matrix`, `DataFrame.select_dtypes(include='category')` is OK, but prefer current patterns.
+        - seaborn: do not use `distplot`, `pairplot` on very large data without sampling; prefer `histplot`, `displot`, `regplot`, or FacetGrid with `.map_dataframe`.
+        - scikit-learn: import from `sklearn.model_selection` (not `sklearn.cross_validation`); for confusion matrices use `ConfusionMatrixDisplay.from_estimator`; set `random_state=42` where relevant.
+        4) Be **defensive**:
+        - Verify required columns exist; if any are missing, raise `ValueError("Missing columns: ...")` early.
+        - Handle missing values sensibly (e.g., drop rows for simple EDA; use `ColumnTransformer` + `SimpleImputer` for modeling).
+        - For categorical features in ML, use `OneHotEncoder(handle_unknown="ignore")` inside a `Pipeline`/`ColumnTransformer` (no `LabelEncoder` on features).
+        5) Keep it **fast** (kernel timeout ~8s):
+        - For plots on large frames (>20k rows), downsample to ~1,000 rows (`df.sample(1000, random_state=42)`) unless aggregation is more appropriate.
+        - Prefer vectorized ops; avoid O(n²) Python loops.
+        6) Always **produce at least one visible result** at the end:
+        - If plotting with matplotlib/seaborn: call `plt.tight_layout(); plt.show()`.
+        - If producing a table or metrics: from `syntaxmatrix.display import show` then `show(object_or_dataframe)`.
+        7) Follow task type conventions:
+        - **EDA/Stats**: compute the requested stat, then show a relevant table (e.g., summary/crosstab) or plot.
+        - **Classification**: train/valid split (`train_test_split`), build a pipeline with scaling/encoding as needed, fit, show accuracy **and** a confusion matrix via `ConfusionMatrixDisplay.from_estimator(...); plt.show()`. Also show `classification_report` as a dataframe if short.
+        - **Regression**: train/valid split, pipeline as needed, fit, show R² and MAE; plot predicted vs actual scatter.
+        - **Correlation/Chi-square/ANOVA**: compute the statistic + p-value and show a concise result table (with `show(...)`) and, when sensible, a small plot (heatmap/bar).
+        8) Don't mutate or recreate target columns if they already exist (e.g., if asked to “predict TARGET”, use `y = df['TARGET']` as-is).
+        9) Keep variable names short and clear; prefer `num_cols` / `cat_cols` discovery by dtype.
+        10) You MUST NOT reference any column outside Allowed columns: {ALLOWED_COLUMNS}\n. 
+        11) If asked to predict/classify, choose the target by matching the task text to Allowed columns: {ALLOWED_COLUMNS}\n and never invent a new name (e.g., 'whether', 'the').
+
+        ### Output
+        Return **only runnable Python** that:
+        - Imports what it needs,
+        - Validates columns,
+        - Solves: {question},
+        - And ends with at least one visible output (`show(...)` and/or `plt.show()`).
         """
 
         def google_generate_code():
@@ -1076,7 +1050,7 @@ class SyntaxMUI:
                         {"role": "system", "content": ai_profile},
                         {"role": "user", "content": instructions},
                         ],
-                    temperature=0.0,
+                    temperature=0.3,
                     max_tokens=2048,
                 )
                 return response.choices[0].message.content
