@@ -513,43 +513,46 @@ def generate_page_html(page_title, website_description):
             return
         _profile = profile
 
-    ai_code_id = f" You are a senior web developer tasked with creating a single-file responsive webpage. "
-    instructions = f"""
-    Generate the webpage following the guidelines given, ensuring images are sourced also.
-    The output must be a single HTML file containing all HTML, CSS (using Tailwind CSS via CDN), and JavaScript (using React via CDN) with no external dependencies beyond CDNs. The page must reflect the essence of the page title in relation to the website's objectives, include a hero section and subsections, and use free, high-quality images from Unsplash or Pexels (licensed for commercial use). Ensure animations (e.g., fade-ins, hover effects) are included, and the design is responsive for all devices. Do not include headers or footers, as they are provisioned by the website. Avoid variable names that might clash with existing ones (e.g., use unique names like 'heroSection', 'subSectionContent'). Follow these guidelines:\n
+    _ai_code_id = f" You are a senior web developer tasked with creating a single-file responsive webpage. "
+    _instructions = f"""
+        Generate the webpage following the guidelines given, ensuring images are sourced also.
+        The output must be a single HTML file containing all HTML, CSS (using Tailwind CSS via CDN), and JavaScript (using React via CDN) with no external dependencies beyond CDNs. The page must reflect the essence of the page title in relation to the website's objectives, include a hero section and subsections, and use free, high-quality images from Unsplash or Pexels (licensed for commercial use). Ensure animations (e.g., fade-ins, hover effects) are included, and the design is responsive for all devices. Do not include headers or footers, as they are provisioned by the website. Avoid variable names that might clash with existing ones (e.g., use unique names like 'heroSection', 'subSectionContent'). Follow these guidelines:\n
 
-    **Input**
-    - Page title: {page_title}
-    - Website description: {website_description}
+        <input>
+            - Page title: {page_title}
+            - Website description: {website_description}
+        </input>
 
-        **Requirements**
-    - Never mount React to document.body or document.documentElement; mount only to <div id="smx-react-root"></div>.
-    - Include <div id="smx-react-root"></div> if React/ReactDOM are used.
-    - Prefer vanilla JS for simple effects (scroll/hover). If you use React, mount via createRoot(document.getElementById('smx-react-root')).
-    - Do not call document.write() or overwrite document.body.innerHTML.
-    - Start elements with class .fade-in hidden (opacity:0, translateY(20px)) and reveal with transitions.
+        <requirements>
+            - Never mount React to document.body or document.documentElement; mount only to <div id="smx-react-root"></div>.
+            - Include <div id="smx-react-root"></div> if React/ReactDOM are used.
+            - Prefer vanilla JS for simple effects (scroll/hover). If you use React, mount via createRoot(document.getElementById('smx-react-root')).
+            - Do not call document.write() or overwrite document.body.innerHTML.
+            - Start elements with class .fade-in hidden (opacity:0, translateY(20px)) and reveal with transitions.
+            - Create a single HTML file with embedded React 
+            - Use JSX via:
+                CDN: (https://cdn.jsdelivr.net/npm/react@18.2.0/umd/react.production.min.js and https://cdn.jsdelivr.net/npm/react-dom@18.2.0/umd/react-dom.production.min.js) 
+                Babel: (https://cdn.jsdelivr.net/npm/@babel/standalone@7.20.6/babel.min.js)
+                Tailwind CSS: (https://cdn.tailwindcss.com).
+            - Structure the page with a hero section (prominent headline, description, call-to-action) and subsections relevant to the page title and objectives.
+            - Use modern JavaScript syntax and JSX for reusable components (e.g., HeroComponent, SectionComponent, SubSectionComponent).
+            - Ensure the design is vibrant, professional, and consistent with the website's theme (infer theme from objectives, e.g., calming colors for health-related sites).
+            - Include animations (e.g., fade-ins using Tailwind or JavaScript) without overwhelming the page.
+            - Source images from Unsplash and/or Pexels, and place them appropriately (e.g., hero section background, subsection images).
+            - Ensure responsiveness using Tailwind's responsive classes (e.g., sm:, md:, lg:).
+            - Avoid <form> onSubmit due to sandbox restrictions; use buttons with click handlers instead.
+            - Use className instead of class in JSX.
+            - Verify the code is complete, functional, and ready to be saved as an HTML file and viewed in a browser.
+        </requirements>
 
-    **Requirements**
-        - Create a single HTML file with embedded React 
-        - Use JSX via:
-            CDN: (https://cdn.jsdelivr.net/npm/react@18.2.0/umd/react.production.min.js and https://cdn.jsdelivr.net/npm/react-dom@18.2.0/umd/react-dom.production.min.js) 
-            Babel: (https://cdn.jsdelivr.net/npm/@babel/standalone@7.20.6/babel.min.js)
-            Tailwind CSS: (https://cdn.tailwindcss.com).
-        - Structure the page with a hero section (prominent headline, description, call-to-action) and subsections relevant to the page title and objectives.
-        - Use modern JavaScript syntax and JSX for reusable components (e.g., HeroComponent, SectionComponent, SubSectionComponent).
-        - Ensure the design is vibrant, professional, and consistent with the website's theme (infer theme from objectives, e.g., calming colors for health-related sites).
-        - Include animations (e.g., fade-ins using Tailwind or JavaScript) without overwhelming the page.
-        - Source images from Unsplash and/or Pexels, and place them appropriately (e.g., hero section background, subsection images).
-        - Ensure responsiveness using Tailwind's responsive classes (e.g., sm:, md:, lg:).
-        - Avoid <form> onSubmit due to sandbox restrictions; use buttons with click handlers instead.
-        - Use className instead of class in JSX.
-        - Verify the code is complete, functional, and ready to be saved as an HTML file and viewed in a browser.
-        
-        Now, for this page title: {page_title}\n, generate html content that aligns with the given website description:\n 
-            {website_description}.\n\n
+        <task>
+            Now, for this page title: {page_title}\n, 
+            generate html content that aligns with the given website description:\n {website_description}.\n\n
+        </task>
 
-        **Output Format**
-        Return only the complete HTML content as a string, with no additional explanation or comments outside the HTML code. Ensure the HTML includes all necessary scripts, styles, and JSX components.
+        <output>
+            Return only the complete HTML content as a string, with no additional explanation or comments outside the HTML code. Ensure the HTML includes all necessary scripts, styles, and JSX components.
+        </task>
     """
 
     from syntaxmatrix.settings import model_map as mm, prompts
@@ -561,7 +564,7 @@ def generate_page_html(page_title, website_description):
     def google_generate_code():
         response = _client.models.generate_content(
             model=_model, 
-            contents=f"{ai_code_id}\n\n{instructions}\n\n"  
+            contents=f"{_ai_code_id}\n\n{_instructions}\n\n"  
         )
         return response.text
 
@@ -570,8 +573,8 @@ def generate_page_html(page_title, website_description):
         try:                 
             args = set_args(
                 model=_model,
-                instructions=ai_code_id,
-                input=instructions,
+                instructions=_ai_code_id,
+                input=_instructions,
                 reasoning_effort=reasoning_effort,
                 verbosity=verbosity,
             )
@@ -582,15 +585,29 @@ def generate_page_html(page_title, website_description):
         except Exception as e:
             return f"Error!"
 
+    def anthropic_generate_code():      
+            try:
+                response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=_ai_code_id,
+                    messages=[{"role": "user", "content":_instructions}],
+                    stream=False,
+                )
+                return response.content[0].text.strip()    
+                   
+            except Exception as e:
+                return f"Error: {str(e)}"
+            
     def openai_sdk_generate_code():
         try:
             response = _client.chat.completions.create(
                 model=_model,
                 messages=[
-                    {"role": "system", "content": ai_code_id},
-                    {"role": "user", "content": instructions},
+                    {"role": "system", "content": _ai_code_id},
+                    {"role": "user", "content": _instructions},
                     ],
-                temperature=0.0,
+                temperature=0.3,
                 max_tokens=2048,
             )
             return response.choices[0].message.content
@@ -603,6 +620,8 @@ def generate_page_html(page_title, website_description):
         html = google_generate_code()
     elif _model in mm.GPT_MODELS_LATEST:
         html = gpt_models_latest_generate_code()
+    elif _provider == "anthropic":
+        html = anthropic_generate_code()
     else:
         html = openai_sdk_generate_code()
 
