@@ -18,15 +18,22 @@ def extract_output_text(resp) -> str:
     return "\n".join(text_parts).strip()
 
 
-def set_args(model, instructions, input, previous_id=None, store=False, reasoning_effort="minimal", verbosity="low"):
-
+def set_args(
+        model, 
+        instructions, 
+        input, previous_id=None, 
+        store=False, 
+        reasoning_effort="minimal", 
+        verbosity="low",
+        truncation="auto",
+    ):
     base_params = {
             "model": model,
             "instructions": instructions,
             "input": input,
             "previous_response_id": previous_id,
             "store": store,
-            "truncation": "auto",
+            "truncation": truncation,
     }
     if model == "gpt-5-chat-latest":
         args = base_params
