@@ -950,3 +950,44 @@ def inject_display_shim(code: str) -> str:
         "\n"
     )
     return shim + code
+
+def strip_spurious_column_tokens(code: str) -> str:
+    """
+    Remove common stop-words ('the','whether', ...) when they appear
+    inside column lists, e.g.:
+        predictors = ['BMI','the','HbA1c']
+        df[['GGT','whether','BMI']]
+    Leaves other strings intact.
+    """
+    STOP = {
+        "the","whether","a","an","and","or","of","to","in","on","for","by",
+        "with","as","at","from","that","this","these","those","is","are","was","were"
+    }
+
+    def _norm(s: str) -> str:
+        return re.sub(r"[^a-z0-9]+", "", s.lower())
+
+    def _clean_list(content: str) -> str:
+        # Rebuild a string list, keeping only non-stopword items
+        items = re.findall(r"(['\"])(.*?)\1", content)
+        if not items:
+            return "[" + content + "]"
+        keep = [f"{q}{s}{q}" for (q, s) in items if _norm(s) not in STOP]
+        return "[" + ", ".join(keep) + "]"
+
+    # Variable assignments: predictors/features/columns/cols = [...]
+    code = re.sub(
+        r"(?m)\b(predictors|features|columns|cols)\s*=\s*\[([^\]]+)\]",
+        lambda m: f"{m.group(1)} = " + _clean_list(m.group(2)),
+        code
+    )
+
+    # df[[ ... ]] selections
+    code = re.sub(
+        r"df\s*\[\s*\[([^\]]+)\]\s*\]",
+        lambda m: "df[" + _clean_list(m.group(1)) + "]",
+        code
+    )
+
+    return code
+
